@@ -11,15 +11,18 @@ var group__opts_group =
     [ "natsOptions_SetName", "group__opts_group.html#ga1c529d347be0fe2eec17c7f4698e283e", null ],
     [ "natsOptions_SetSecure", "group__opts_group.html#gaa1f09416d443fa7a6af6b695da563eba", null ],
     [ "natsOptions_TLSHandshakeFirst", "group__opts_group.html#gac530a5d4cc93158047fc17c79dac6812", null ],
+    [ "natsOptions_AllowConcurrentTLSHandshakes", "group__opts_group.html#ga6c168a80271bb0f7807ce80573ab45a3", null ],
     [ "natsOptions_LoadCATrustedCertificates", "group__opts_group.html#ga2cd6563694a439b3949a31fd81103099", null ],
+    [ "natsOptions_LoadCATrustedCertificatesPath", "group__opts_group.html#ga8b6db9efb9adaa62ced649c3d26c1465", null ],
     [ "natsOptions_SetCATrustedCertificates", "group__opts_group.html#gafb30794fc2ae74b9e0bd8fb609b901c8", null ],
     [ "natsOptions_LoadCertificatesChain", "group__opts_group.html#ga36943e2ba53d05407cdabc4e7e96484b", null ],
+    [ "natsOptions_LoadCertificatesChainDynamic", "group__opts_group.html#gaa982664124e0d98fa1c976e8568fd5e8", null ],
     [ "natsOptions_SetCertificatesChain", "group__opts_group.html#gae98f0f9034e93941767ab1ae6eec2c0c", null ],
     [ "natsOptions_SetCiphers", "group__opts_group.html#ga5698f020e8eb3e7440eb073fe08ef62c", null ],
     [ "natsOptions_SetCipherSuites", "group__opts_group.html#ga2b7f144b011d8ce62941b608a8f324f0", null ],
     [ "natsOptions_SetExpectedHostname", "group__opts_group.html#ga0ba43ba9930df385e4781b12be9f2851", null ],
     [ "natsOptions_SkipServerVerification", "group__opts_group.html#ga6f804ec44adc299989fe623570679da3", null ],
-    [ "natsOptions_SetSSLVerificationCallback", "group__opts_group.html#gaa2268dcf2f380b18ddb0e985a6ff7541", null ],
+    [ "natsOptions_SetSSLVerificationCallback", "group__opts_group.html#ga241477d90abb58ada7001cd676d293cb", null ],
     [ "natsOptions_SetVerbose", "group__opts_group.html#gaa16bfd09ef318af18c27a0e199681b69", null ],
     [ "natsOptions_SetPedantic", "group__opts_group.html#ga26f166af20de98bec67bc6cc916f769e", null ],
     [ "natsOptions_SetPingInterval", "group__opts_group.html#gae68fb615835364c0809555e8dc93f57e", null ],
@@ -33,6 +36,7 @@ var group__opts_group =
     [ "natsOptions_SetReconnectBufSize", "group__opts_group.html#gaa0d4b7ece8477cb9879f0dafff3456a5", null ],
     [ "natsOptions_SetMaxPendingMsgs", "group__opts_group.html#ga95510436eee06f9992ded96a44795c40", null ],
     [ "natsOptions_SetMaxPendingBytes", "group__opts_group.html#ga77afd954ca548054631215e511468e60", null ],
+    [ "natsOptions_SetProxyConnHandler", "group__opts_group.html#gad9199e095332535981db1582acea90d1", null ],
     [ "natsOptions_SetErrorHandler", "group__opts_group.html#ga127ec7a8196b453947a7fa9a64096cbd", null ],
     [ "natsOptions_SetClosedCB", "group__opts_group.html#ga44410242e73134e5bb51ef27904a9253", null ],
     [ "natsOptions_SetDisconnectedCB", "group__opts_group.html#gadc8dc0cedd91bda71d544f3dedc4a039", null ],
