@@ -29,6 +29,7 @@ var nats_8h =
     [ "natsMsg", "group__types_group.html#gadcab54026c4ed78f344ce03ce31bb61a", null ],
     [ "natsOptions", "group__types_group.html#gabcc48b40a81fe302188f4ee06ea9c54e", null ],
     [ "natsInbox", "group__types_group.html#ga206c3d4d6f4f6f96fd2cae53a3df31c1", null ],
+    [ "natsHeader", "group__types_group.html#gac2df3a141cb6a868f1ce4c0f27e726f2", null ],
     [ "natsClientConfig", "group__types_group.html#gad29b6af20b875a1b7890ab8f0675287d", null ],
     [ "natsMsgList", "group__types_group.html#gafd5523161ec3783e79719cb9a9a66b5b", null ],
     [ "natsMetadata", "group__types_group.html#ga3b454f3c6ac697a3cdc5bdd3c9ece12b", null ],
@@ -57,6 +58,7 @@ var nats_8h =
     [ "jsSubOptions", "group__types_group.html#gaccfaac2079656ffd40d003e4de5d2280", null ],
     [ "jsSequencePair", "group__types_group.html#ga39011d30b295759b7f6ca0a7539dff8f", null ],
     [ "jsSequenceInfo", "group__types_group.html#ga27e1a5d5b513f9eb7d61a17db71f8003", null ],
+    [ "jsPriorityGroupState", "group__types_group.html#gacb09dc9c012f1835da1d547790aa2ebf", null ],
     [ "jsConsumerInfo", "group__types_group.html#ga2f21bb79884e56a5613d7fe76b11b1e5", null ],
     [ "jsConsumerInfoList", "group__types_group.html#gadad3bf72baae970662248d82d9b05d0a", null ],
     [ "jsConsumerNamesList", "group__types_group.html#gad00ab4381eec504ada3272aa9ff8adb2", null ],
@@ -87,6 +89,21 @@ var nats_8h =
     [ "kvPurgeOptions", "group__types_group.html#ga90e8de23c4468005488bde690a2ffe9d", null ],
     [ "kvEntryList", "group__types_group.html#ga0125d394a3cbae2a1713eed8fab7f78e", null ],
     [ "kvKeysList", "group__types_group.html#gab36492d9d4370337cfed80edce4144e0", null ],
+    [ "objStore", "group__types_group.html#ga0dbdf6ef78b63bfeeb8551519ba57c5d", null ],
+    [ "objStorePut", "group__types_group.html#ga00926d2a2f92b993a9e488491f68f2da", null ],
+    [ "objStoreGet", "group__types_group.html#gac9635b7be7110db17b5e61bb5624aa95", null ],
+    [ "objStoreWatcher", "group__types_group.html#gae2a5ab7a7d3b50688d084102afb9c982", null ],
+    [ "objStoreConfig", "group__types_group.html#gafd04fb1b404bc43c0833bbe9cc55d704", null ],
+    [ "objStoreNamesList", "group__types_group.html#ga1847fb7592bd0fda6e7db8de847b1d4e", null ],
+    [ "objStoreStatus", "group__types_group.html#ga175ca9f21ae86d127e1b42cdfc16214a", null ],
+    [ "objStoreStatusesList", "group__types_group.html#gafe099c8a8b5901620972527862d49105", null ],
+    [ "objStoreLink", "group__types_group.html#gadd629f77cc9128f2c29df555e537c3cd", null ],
+    [ "objStoreMetaOptions", "group__types_group.html#ga357fc821577119320265d1766718f94f", null ],
+    [ "objStoreMeta", "group__types_group.html#gad33ce5e6a4cf28a6c1d350c9d938627a", null ],
+    [ "objStoreInfo", "group__types_group.html#gad161e0bbe07d47847c9cc01c8307e934", null ],
+    [ "objStoreInfoList", "group__types_group.html#ga1f2a7d44e4ce511117c352cf6d10ff38", null ],
+    [ "objStoreOptions", "group__types_group.html#gac4c724c2d6c819a57db7e97fc0d5dddb", null ],
+    [ "objStoreWatchOptions", "group__types_group.html#ga375e2f7b356f1e92d6d4eaaa77192b57", null ],
     [ "stanConnection", "group__types_group.html#ga9e826493769d23086cfccefe95cdf64c", null ],
     [ "stanSubscription", "group__types_group.html#gae4dae869fb614536f0f027c2e2660cc5", null ],
     [ "stanMsg", "group__types_group.html#ga2cf5db7703b42d97abe56a3e83b2a87d", null ],
@@ -94,6 +111,7 @@ var nats_8h =
     [ "stanSubOptions", "group__types_group.html#ga023712711f5c289663fc2223e83686d3", null ],
     [ "natsMsgHandler", "group__callbacks_group.html#gad1a5ac566893e13dc8c81ac0e9c87afe", null ],
     [ "natsConnectionHandler", "group__callbacks_group.html#gacdef6aff3e47953f19e35857ab8e274c", null ],
+    [ "natsProxyConnHandler", "group__callbacks_group.html#gae1d0ec90461ccdb105d00e1030806faa", null ],
     [ "natsErrHandler", "group__callbacks_group.html#ga9e511dffa471dfb971b7dd2b12329626", null ],
     [ "natsEvLoop_Attach", "group__callbacks_group.html#ga245eab0a01a485e40fba267f84ec037f", null ],
     [ "natsEvLoop_ReadAddRemove", "group__callbacks_group.html#gaea4c125ecfb43eaf43da20e8444c2aaa", null ],
@@ -104,6 +122,7 @@ var nats_8h =
     [ "natsTokenHandler", "group__callbacks_group.html#ga4b02de70fe9380d184fd01d87527f499", null ],
     [ "natsOnCompleteCB", "group__callbacks_group.html#ga245131e64f1d0dff7edc8ed874a07e9a", null ],
     [ "natsCustomReconnectDelayHandler", "group__callbacks_group.html#ga3353d4b92851c52121f65aaf0684cba4", null ],
+    [ "natsSSLVerifyCb", "group__callbacks_group.html#gac45beaf6d26ef2c335ba499e4be5a896", null ],
     [ "jsPubAckErrHandler", "group__callbacks_group.html#ga954768cc1d3388bb6ab723e777647992", null ],
     [ "jsPubAckHandler", "group__callbacks_group.html#ga4f66e065bd918f02510d4c53d8a5b729", null ],
     [ "stanPubAckHandler", "group__callbacks_group.html#gad5d6a685731b3bf635995b7375af4d18", null ],
@@ -173,6 +192,7 @@ var nats_8h =
     [ "nats_CheckCompatibility", "group__library_group.html#ga8c2ad4df801bd9d11564587ed3a7081e", null ],
     [ "nats_Now", "group__library_group.html#gaa3c10ba3ae001595007ad0dc5dccc15e", null ],
     [ "nats_NowInNanoSeconds", "group__library_group.html#gacf5e423920d6a647df3bbf7de39d5223", null ],
+    [ "nats_NowMonotonicInNanoSeconds", "group__library_group.html#gaaca06768e23df2a1261316f57cc66543", null ],
     [ "nats_Sleep", "group__library_group.html#gad5040264cd4b1404956babf3c03a4f09", null ],
     [ "nats_GetLastError", "group__library_group.html#gadecfd49a58b581dbba40da77b195fd85", null ],
     [ "nats_GetLastErrorStack", "group__library_group.html#gaca24172e1b97ca01cee29ca437f5702e", null ],
@@ -197,15 +217,18 @@ var nats_8h =
     [ "natsOptions_SetName", "group__opts_group.html#ga1c529d347be0fe2eec17c7f4698e283e", null ],
     [ "natsOptions_SetSecure", "group__opts_group.html#gaa1f09416d443fa7a6af6b695da563eba", null ],
     [ "natsOptions_TLSHandshakeFirst", "group__opts_group.html#gac530a5d4cc93158047fc17c79dac6812", null ],
+    [ "natsOptions_AllowConcurrentTLSHandshakes", "group__opts_group.html#ga6c168a80271bb0f7807ce80573ab45a3", null ],
     [ "natsOptions_LoadCATrustedCertificates", "group__opts_group.html#ga2cd6563694a439b3949a31fd81103099", null ],
+    [ "natsOptions_LoadCATrustedCertificatesPath", "group__opts_group.html#ga8b6db9efb9adaa62ced649c3d26c1465", null ],
     [ "natsOptions_SetCATrustedCertificates", "group__opts_group.html#gafb30794fc2ae74b9e0bd8fb609b901c8", null ],
     [ "natsOptions_LoadCertificatesChain", "group__opts_group.html#ga36943e2ba53d05407cdabc4e7e96484b", null ],
+    [ "natsOptions_LoadCertificatesChainDynamic", "group__opts_group.html#gaa982664124e0d98fa1c976e8568fd5e8", null ],
     [ "natsOptions_SetCertificatesChain", "group__opts_group.html#gae98f0f9034e93941767ab1ae6eec2c0c", null ],
     [ "natsOptions_SetCiphers", "group__opts_group.html#ga5698f020e8eb3e7440eb073fe08ef62c", null ],
     [ "natsOptions_SetCipherSuites", "group__opts_group.html#ga2b7f144b011d8ce62941b608a8f324f0", null ],
     [ "natsOptions_SetExpectedHostname", "group__opts_group.html#ga0ba43ba9930df385e4781b12be9f2851", null ],
     [ "natsOptions_SkipServerVerification", "group__opts_group.html#ga6f804ec44adc299989fe623570679da3", null ],
-    [ "natsOptions_SetSSLVerificationCallback", "group__opts_group.html#gaa2268dcf2f380b18ddb0e985a6ff7541", null ],
+    [ "natsOptions_SetSSLVerificationCallback", "group__opts_group.html#ga241477d90abb58ada7001cd676d293cb", null ],
     [ "natsOptions_SetVerbose", "group__opts_group.html#gaa16bfd09ef318af18c27a0e199681b69", null ],
     [ "natsOptions_SetPedantic", "group__opts_group.html#ga26f166af20de98bec67bc6cc916f769e", null ],
     [ "natsOptions_SetPingInterval", "group__opts_group.html#gae68fb615835364c0809555e8dc93f57e", null ],
@@ -219,6 +242,7 @@ var nats_8h =
     [ "natsOptions_SetReconnectBufSize", "group__opts_group.html#gaa0d4b7ece8477cb9879f0dafff3456a5", null ],
     [ "natsOptions_SetMaxPendingMsgs", "group__opts_group.html#ga95510436eee06f9992ded96a44795c40", null ],
     [ "natsOptions_SetMaxPendingBytes", "group__opts_group.html#ga77afd954ca548054631215e511468e60", null ],
+    [ "natsOptions_SetProxyConnHandler", "group__opts_group.html#gad9199e095332535981db1582acea90d1", null ],
     [ "natsOptions_SetErrorHandler", "group__opts_group.html#ga127ec7a8196b453947a7fa9a64096cbd", null ],
     [ "natsOptions_SetClosedCB", "group__opts_group.html#ga44410242e73134e5bb51ef27904a9253", null ],
     [ "natsOptions_SetDisconnectedCB", "group__opts_group.html#gadc8dc0cedd91bda71d544f3dedc4a039", null ],
@@ -267,6 +291,15 @@ var nats_8h =
     [ "stanSubOptions_Destroy", "group__stan_sub_opts_group.html#ga1b56877d0a6729e148c9c288e2b88e3f", null ],
     [ "natsInbox_Create", "group__inbox_group.html#gaa1ec779a0b7ead54b78da05533848b6d", null ],
     [ "natsInbox_Destroy", "group__inbox_group.html#gabd6444fb8f28afb9c2b6645945f46cfe", null ],
+    [ "natsHeader_New", "group__header_group.html#ga4aa46d3e432089e922b274c48108794d", null ],
+    [ "natsHeader_Set", "group__header_group.html#ga72f00a2daf05b155ab80210e27db7d0c", null ],
+    [ "natsHeader_Add", "group__header_group.html#ga63f5995a9503339f1965a6cb784c3232", null ],
+    [ "natsHeader_Get", "group__header_group.html#ga658d0d3457c6799d8b6a7ef49a16fdfb", null ],
+    [ "natsHeader_Values", "group__header_group.html#gaa5689e970b5898e7293709df9e666ec7", null ],
+    [ "natsHeader_Keys", "group__header_group.html#ga2f0d89256c2951f40abc86b1d2e540d2", null ],
+    [ "natsHeader_KeysCount", "group__header_group.html#gab4ccecb9af674a68a9e1fd7496989f33", null ],
+    [ "natsHeader_Delete", "group__header_group.html#ga133a3368231a991d5603fc20e0a61985", null ],
+    [ "natsHeader_Destroy", "group__header_group.html#ga4c2339c51f5d73650723b8f4cc2a57b2", null ],
     [ "natsMsgList_Destroy", "group__msg_group.html#ga1a091d24f939d881bf04fba78b8995c2", null ],
     [ "natsMsg_Create", "group__msg_group.html#ga098e4fec1c5a71c00a0d092fbd6d1a21", null ],
     [ "natsMsg_GetSubject", "group__msg_group.html#gad7cad38946648e3047aa0665a3dd230a", null ],
@@ -292,6 +325,7 @@ var nats_8h =
     [ "natsConnection_ProcessReadEvent", "group__conn_mgt_group.html#gaa89c06e30e19ff361125bfc9114d89a8", null ],
     [ "natsConnection_ProcessCloseEvent", "group__conn_mgt_group.html#ga9b0b13505d2dc85f49a5554c8a164876", null ],
     [ "natsConnection_ProcessWriteEvent", "group__conn_mgt_group.html#gad81b603b84c0180aefc6d5ebad7f2a47", null ],
+    [ "natsConnection_ProcessDetachedEvent", "group__conn_mgt_group.html#ga9a6580ac5fd93818f56d72e7399ba84f", null ],
     [ "natsConnection_ConnectTo", "group__conn_mgt_group.html#gafb83c8d7970ba68be0e6c40c38cdfde4", null ],
     [ "natsConnection_IsClosed", "group__conn_mgt_group.html#ga530f0f1c75c58a81aae1a59f15b46d9f", null ],
     [ "natsConnection_IsReconnecting", "group__conn_mgt_group.html#ga5aa349fc3895dde772671b324b07a688", null ],
@@ -424,6 +458,7 @@ var nats_8h =
     [ "jsFetchRequest_Init", "group__js_sub_group.html#ga1c3a62de8cd4855ae61ea4f67417a43b", null ],
     [ "js_PullSubscribeAsync", "group__js_sub_group.html#ga938d410675ab09fa8c21896ab61bed0a", null ],
     [ "natsSubscription_FetchRequest", "group__js_sub_group.html#ga676292505e7fde8688cfd886b79a10ed", null ],
+    [ "js_UnpinConsumer", "group__js_sub_group.html#ga4e17ab573d73cd526524ce3066c52690", null ],
     [ "natsSubscription_GetConsumerInfo", "group__js_sub_group.html#gaae716a1431db065744c079b71a9f4c2e", null ],
     [ "natsSubscription_GetSequenceMismatch", "group__js_sub_group.html#ga0daed9f0d2d00cb14314ecc180a6fa84", null ],
     [ "natsMsg_GetMetaData", "group__js_msg.html#gacf48e59038fab35849e9dc6f8fcf6328", null ],
@@ -484,6 +519,49 @@ var nats_8h =
     [ "kvStatus_Replicas", "group__kv_status.html#ga86b114f4dac9f06df86101f84bd497b2", null ],
     [ "kvStatus_Bytes", "group__kv_status.html#ga6db13a3b26c7c17633623da5f27978ff", null ],
     [ "kvStatus_Destroy", "group__kv_status.html#ga5eb3d824c1873af705beee4798246a08", null ],
+    [ "objStoreConfig_Init", "group__obs_group_mgt.html#ga361d59b23c11ea4605a8d694ecdb2493", null ],
+    [ "js_CreateObjectStore", "group__obs_group_mgt.html#ga565dbd257c11076db238ce44172b3045", null ],
+    [ "js_UpdateObjectStore", "group__obs_group_mgt.html#gabd12d187b7700e89cf547a130394990f", null ],
+    [ "js_ObjectStore", "group__obs_group_mgt.html#gaca8488f4438ca432064f601592d23cca", null ],
+    [ "js_ObjectStoreNames", "group__obs_group_mgt.html#ga1254468c5909068e20c9f6cfacfc5205", null ],
+    [ "objStoreNamesList_Destroy", "group__obs_group_mgt.html#ga9e058607b2c9b86cab5813094b8b6eb3", null ],
+    [ "js_ObjectStoreStatuses", "group__obs_group_mgt.html#ga521c502c6dc6da6f7d45e7b4f2838b25", null ],
+    [ "objStoreStatusesList_Destroy", "group__obs_group_mgt.html#ga614afbdc361c98a33c2be31720a7d07b", null ],
+    [ "js_DeleteObjectStore", "group__obs_group_mgt.html#ga26c92a018f6653812b335cb588f172cc", null ],
+    [ "objStoreOptions_Init", "group__obs_mgt.html#ga69d20b8cad08d88d6e35b29ce5cdd25c", null ],
+    [ "objStore_GetInfo", "group__obs_mgt.html#ga6be233c0be6ea15743d0a323f73212a8", null ],
+    [ "objStoreInfo_Destroy", "group__obs_mgt.html#ga022cb685f1c3861d76dbb168446a23d1", null ],
+    [ "objStore_UpdateMeta", "group__obs_mgt.html#ga8e783138c1bbff15696df7598fd73428", null ],
+    [ "objStore_Delete", "group__obs_mgt.html#ga83fee26eccf5b88f0aec63cc61c86800", null ],
+    [ "objStore_AddLink", "group__obs_mgt.html#ga714e170b0480b26ee2649972a781798e", null ],
+    [ "objStore_AddBucketLink", "group__obs_mgt.html#ga6614ef18192b0934d5edec5aff069f24", null ],
+    [ "objStore_Seal", "group__obs_mgt.html#gaf1a2fc31df2c4a8b9476bce12feaa5d2", null ],
+    [ "objStoreWatchOptions_Init", "group__obs_mgt.html#ga0902c54372c1e3ff63cbeca5839cd77b", null ],
+    [ "objStore_Watch", "group__obs_mgt.html#gac0daaef27795e786c874f55faa7a04e8", null ],
+    [ "objStoreWatcher_Next", "group__obs_mgt.html#gac88889427d4a339b4fcb978b4cc1943e", null ],
+    [ "objStoreWatcher_Stop", "group__obs_mgt.html#ga73ce29a44259fb63293a9c3c98f026dc", null ],
+    [ "objStoreWatcher_Destroy", "group__obs_mgt.html#ga2e7a7cf688985b4ce7df97ef5904b7c8", null ],
+    [ "objStore_List", "group__obs_mgt.html#gaf7ea0ad61e9d4077d536be882e78802e", null ],
+    [ "objStoreInfoList_Destroy", "group__obs_mgt.html#gaea3a2dbd39cd6e69a01391548add9a13", null ],
+    [ "objStore_Status", "group__obs_mgt.html#ga587bf1e11af52cdd0ef356aadb63aafe", null ],
+    [ "objStoreStatus_Destroy", "group__obs_mgt.html#ga7ef04461459b3b1171f07950eb434712", null ],
+    [ "objStore_Destroy", "group__obs_mgt.html#ga64343996cbdebf5dee52dd60daff25ce", null ],
+    [ "objStoreMeta_Init", "group__obs_group.html#gab10be9afeb87609da24f10ea25556412", null ],
+    [ "objStore_Put", "group__obs_group.html#ga7f905e1cda4e13b4a44f0e614adec6b6", null ],
+    [ "objStorePut_Add", "group__obs_group.html#ga1c406a0cc622f74dff298baa6df14ee2", null ],
+    [ "objStorePut_Complete", "group__obs_group.html#gab72474e93b75b51c381117c85efa84e4", null ],
+    [ "objStorePut_Destroy", "group__obs_group.html#gac40222ed56aaeac0955a3a87819f7ed7", null ],
+    [ "objStore_PutString", "group__obs_group.html#gac0484b53e470c6a6821df662eb52922e", null ],
+    [ "objStore_PutBytes", "group__obs_group.html#gabfc126056112ae8522a70ace6900e3a3", null ],
+    [ "objStore_PutFile", "group__obs_group.html#ga792f04ea3c22e1a0aebdbbc38c62ff04", null ],
+    [ "objStore_Get", "group__obs_group.html#gab967cd5a4c6ed2b403ec9baa374543eb", null ],
+    [ "objStoreGet_Info", "group__obs_group.html#gad599fef84e3e015d0d8c1e62c9e1b986", null ],
+    [ "objStoreGet_Read", "group__obs_group.html#gab4388a36f33aff20a5b8a0b32b3a6b64", null ],
+    [ "objStoreGet_ReadAll", "group__obs_group.html#ga4ac8b8af8aee703a07acfd56d47cc7c5", null ],
+    [ "objStoreGet_Destroy", "group__obs_group.html#ga24d9fdf73cae9cc89e889128d6de8243", null ],
+    [ "objStore_GetString", "group__obs_group.html#gab7f016290a9a0407ebb7824461a506b7", null ],
+    [ "objStore_GetBytes", "group__obs_group.html#gafb7f87a99c7e2b0fe14f8044bb82e032", null ],
+    [ "objStore_GetFile", "group__obs_group.html#gab8ac22b959354953c88119d3c1a74408", null ],
     [ "micro_AddService", "group__micro_service_functions.html#ga2986a9751147b6f77064b5739635c2c1", null ],
     [ "microService_AddEndpoint", "group__micro_service_functions.html#gadcab5687b72ec24ef7ae647ea844ebc7", null ],
     [ "microService_AddGroup", "group__micro_service_functions.html#ga26c62ec5b8ed46e1503bb62d8b066d9c", null ],
