@@ -7,6 +7,9 @@ var structjs_options_pull_subscribe_async =
     [ "CompleteHandler", "structjs_options_pull_subscribe_async.html#a6224bf50d314a83ed2df2c84a6966055", null ],
     [ "CompleteHandlerClosure", "structjs_options_pull_subscribe_async.html#aa5437f766db36d61595cc0471b2b65c2", null ],
     [ "Heartbeat", "structjs_options_pull_subscribe_async.html#a6583dfdee172d82b6877d9e6ff4e845c", null ],
+    [ "Group", "structjs_options_pull_subscribe_async.html#ad133f4ce6e9147f991ba837fc40ed538", null ],
+    [ "MinPending", "structjs_options_pull_subscribe_async.html#acf2ebfa655aa25ac8abb1e2665fa90da", null ],
+    [ "MinAckPending", "structjs_options_pull_subscribe_async.html#a5f49861af9e790fb963ddea5c6c01594", null ],
     [ "FetchSize", "structjs_options_pull_subscribe_async.html#a1bf6fa8ddd19698bd82f4c27ddb06a9f", null ],
     [ "KeepAhead", "structjs_options_pull_subscribe_async.html#ae50d78c4012666aca20b7a01341d8d07", null ],
     [ "NextHandler", "structjs_options_pull_subscribe_async.html#a591cac37de66ace6a96f7c73fc305661", null ],
