@@ -32,6 +32,7 @@ typedef struct
     struct event        *read;
     struct event        *write;
     struct event        *keepActive;
+    natsSock            socketToClose;
 
 } natsLibeventEvents;
 
@@ -82,6 +83,32 @@ keepAliveCb(evutil_socket_t fd, short flags, void * arg)
     // do nothing...
 }
 
+static void
+natsLibeventEvents_free(natsLibeventEvents *nle, bool processDetachedEvents)
+{
+    if (nle->read != NULL)
+        event_free(nle->read);
+    if (nle->write != NULL)
+        event_free(nle->write);
+    if (nle->keepActive != NULL)
+    {
+        event_active(nle->keepActive, 0, 0);
+        event_free(nle->keepActive);
+    }
+    if (processDetachedEvents)
+        natsConnection_ProcessDetachedEvent(nle->nc);
+    free(nle);
+}
+
+// This callback is invoked from the event loop thread and will free the
+// `natsLibeventEvents` object.
+static void
+_freeCb(evutil_socket_t ignoredSocket, short ignoredEvent, void *arg)
+{
+    natsLibeventEvents *nle = (natsLibeventEvents*) arg;
+    natsLibeventEvents_free(nle, true);
+}
+
 /** \brief Attach a connection to the given event loop.
  *
  * This callback is invoked after `NATS` library has connected, or reconnected.
@@ -100,6 +127,7 @@ natsLibevent_Attach(void **userData, void *loop, natsConnection *nc, natsSock so
     struct event_base   *libeventLoop = (struct event_base*) loop;
     natsLibeventEvents  *nle          = (natsLibeventEvents*) (*userData);
     natsStatus          s             = NATS_OK;
+    bool                created       = false;
 
     // This is the first attach (when reconnecting, nle will be non-NULL).
     if (nle == NULL)
@@ -108,6 +136,8 @@ natsLibevent_Attach(void **userData, void *loop, natsConnection *nc, natsSock so
         if (nle == NULL)
             return NATS_NO_MEMORY;
 
+        // Indicate that we have created the object here (in case we get a failure).
+        created   = true;
         nle->nc   = nc;
         nle->loop = libeventLoop;
 
@@ -152,21 +182,21 @@ natsLibevent_Attach(void **userData, void *loop, natsConnection *nc, natsSock so
 
     if (s == NATS_OK)
         *userData = (void*) nle;
-    else
-        natsLibevent_Detach((void*) nle);
+    else if (created)
+        natsLibeventEvents_free(nle, false);
 
     return s;
 }
 
 static void
-_closeCb(evutil_socket_t fd, short event, void *arg)
+_closeCb(evutil_socket_t ignoredSocket, short ignoredEvent, void *arg)
 {
-    natsSock socket = (natsSock) fd;
+    natsLibeventEvents  *nle = (natsLibeventEvents*) arg;
 
     // We have stopped polling for the "READ" event and are now in the
     // event loop thread and invoke this so that the NATS C client
     // library can proceed with the close of the socket/connection.
-    natsConnection_ProcessCloseEvent(&socket);
+    natsConnection_ProcessCloseEvent(&(nle->socketToClose));
 }
 
 /** \brief Start or stop polling on READ events.
@@ -193,7 +223,8 @@ natsLibevent_Read(void *userData, bool add)
         {
             // This will schedule a one-time event that guarantees that the
             // callback `_closeCb` will be invoked from the event loop thread.
-            res = event_base_once(nle->loop, socket, EV_TIMEOUT, _closeCb, (void*) nle, NULL);
+            nle->socketToClose = (natsSock) socket;
+            res = event_base_once(nle->loop, -1, EV_TIMEOUT, _closeCb, (void*) nle, NULL);
         }
     }
 
@@ -235,19 +266,11 @@ natsLibevent_Detach(void *userData)
 {
     natsLibeventEvents *nle = (natsLibeventEvents*) userData;
 
-    if (nle->read != NULL)
-        event_free(nle->read);
-    if (nle->write != NULL)
-        event_free(nle->write);
-    if (nle->keepActive != NULL)
-    {
-        event_active(nle->keepActive, 0, 0);
-        event_free(nle->keepActive);
-    }
+    // This will schedule a one-time event that guarantees that the
+    // callback `_freeCb` will be invoked from the event loop thread.
+    int res = event_base_once(nle->loop, -1, EV_TIMEOUT, _freeCb, (void*) nle, NULL);
 
-    free(nle);
-
-    return NATS_OK;
+    return (res == 0 ? NATS_OK : NATS_ERR);
 }
 
 /** @} */ // end of libeventFunctions
