@@ -237,10 +237,9 @@ uvAsyncAttach(natsLibuvEvents *nle)
 }
 
 static void
-uvFinalCloseCb(uv_handle_t* handle)
+natsLibuvEvents_free(natsLibuvEvents *nle, bool processDetachedEvent)
 {
-    natsLibuvEvents *nle = (natsLibuvEvents*) handle->data;
-    natsLibuvEvent  *event;
+    natsLibuvEvent *event;
 
     while ((event = nle->head) != NULL)
     {
@@ -248,11 +247,23 @@ uvFinalCloseCb(uv_handle_t* handle)
         free(event);
     }
     free(nle->scheduler);
-    uv_mutex_destroy(nle->lock);
-    free(nle->lock);
+    if (nle->lock != NULL)
+    {
+        uv_mutex_destroy(nle->lock);
+        free(nle->lock);
+    }
+    if (processDetachedEvent)
+        natsConnection_ProcessDetachedEvent(nle->nc);
     free(nle);
 }
 
+static void
+uvFinalCloseCb(uv_handle_t* handle)
+{
+    natsLibuvEvents *nle = (natsLibuvEvents*) handle->data;
+    natsLibuvEvents_free(nle, true);
+}
+
 static void
 uvAsyncDetach(natsLibuvEvents *nle)
 {
@@ -346,6 +357,7 @@ natsLibuv_Attach(void **userData, void *loop, natsConnection *nc, natsSock socke
     bool            sched   = false;
     natsLibuvEvents *nle    = (natsLibuvEvents*) (*userData);
     natsStatus      s       = NATS_OK;
+    bool            created = false;
 
     sched = ((uv_key_get(&uvLoopThreadKey) != loop) ? true : false);
 
@@ -360,6 +372,9 @@ natsLibuv_Attach(void **userData, void *loop, natsConnection *nc, natsSock socke
         if (nle == NULL)
             return NATS_NO_MEMORY;
 
+        // Indicate that we have created the object here (in case we get a failure).
+        created = true;
+
         nle->lock = (uv_mutex_t*) malloc(sizeof(uv_mutex_t));
         if (nle->lock == NULL)
             s = NATS_NO_MEMORY;
@@ -400,8 +415,8 @@ natsLibuv_Attach(void **userData, void *loop, natsConnection *nc, natsSock socke
 
     if (s == NATS_OK)
         *userData = (void*) nle;
-    else
-        natsLibuv_Detach((void*) nle);
+    else if (created)
+        natsLibuvEvents_free(nle, false);
 
     return s;
 }
@@ -421,6 +436,10 @@ natsLibuv_Read(void *userData, bool add)
     natsStatus      s    = NATS_OK;
     bool            sched;
 
+    // If we remove, first stop polling immediately, then proceed as usual.
+    if (!add)
+        uv_poll_stop(nle->handle);
+
     sched = ((uv_key_get(&uvLoopThreadKey) != nle->loop) ? true : false);
 
     // If this call is made from a different thread than the event loop's
