@@ -1,4 +1,4 @@
-// Copyright 2015-2024 The NATS Authors
+// Copyright 2015-2025 The NATS Authors
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
 // You may obtain a copy of the License at
@@ -46,7 +46,8 @@ typedef struct __natsLibTimers
     natsMutex *lock;
     natsCondition *cond;
     natsThread *thread;
-    natsTimer *timers;
+    natsTimer *head;
+    natsTimer *tail;
     int count;
     bool changed;
     bool shutdown;
@@ -90,9 +91,7 @@ typedef struct __natsLib
     // Leave these fields before 'refs'
     natsMutex *lock;
     volatile bool wasOpenedOnce;
-    bool sslInitialized;
     natsThreadLocal errTLKey;
-    natsThreadLocal sslTLKey;
     natsThreadLocal natsThreadKey;
     bool initialized;
     bool closed;
@@ -135,6 +134,4 @@ void nats_freeDispatcherPool(natsDispatcherPool *pool);
 void nats_signalDispatcherPoolToShutdown(natsDispatcherPool *pool);
 void nats_waitForDispatcherPoolShutdown(natsDispatcherPool *pool);
 
-void nats_cleanupThreadSSL(void *localStorage);
-
 #endif // GLIBP_H_
