@@ -266,7 +266,7 @@ marshal_info(natsBuffer **new_buf, microServiceInfo *info)
         {
             IFOK(s, natsBuf_AppendByte(buf, '{'));
             IFOK_attr("name", info->Endpoints[i].Name, "");
-            IFOK(s, nats_marshalMetadata(buf, true, "metadata", info->Endpoints[i].Metadata));
+            IFOK(s, nats_marshalMetadata(buf, true, "metadata", &(info->Endpoints[i].Metadata)));
             IFOK(s, natsBuf_AppendByte(buf, ','));
             if (!nats_IsStringEmpty(info->Endpoints[i].QueueGroup))
                 IFOK_attr("queue_group", info->Endpoints[i].QueueGroup, ",");
@@ -279,7 +279,7 @@ marshal_info(natsBuffer **new_buf, microServiceInfo *info)
     }
 
     IFOK_attr("id", info->Id, "");
-    IFOK(s, nats_marshalMetadata(buf, true, "metadata", info->Metadata));
+    IFOK(s, nats_marshalMetadata(buf, true, "metadata", &(info->Metadata)));
     IFOK(s, natsBuf_AppendByte(buf, ','));
     IFOK_attr("name", info->Name, ",");
     IFOK_attr("type", info->Type, ",");
@@ -325,7 +325,7 @@ marshal_stats(natsBuffer **new_buf, microServiceStats *stats)
                 IFOK_attr("queue_group", ep->QueueGroup, ",");
             IFOK(s, nats_marshalLong(buf, false, "num_requests", ep->NumRequests));
             IFOK(s, nats_marshalLong(buf, true, "num_errors", ep->NumErrors));
-            IFOK(s, nats_marshalDuration(buf, true, "average_processing_time", ep->AverageProcessingTimeNanoseconds));
+            IFOK(s, nats_marshalLong(buf, true, "average_processing_time", ep->AverageProcessingTimeNanoseconds));
             IFOK(s, natsBuf_AppendByte(buf, ','));
             IFOK_attr("last_error", ep->LastErrorString, "");
             IFOK(s, natsBuf_AppendByte(buf, '}'));
