@@ -1,4 +1,4 @@
-// Copyright 2015-2024 The NATS Authors
+// Copyright 2015-2025 The NATS Authors
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
 // You may obtain a copy of the License at
@@ -25,12 +25,17 @@
 #include <openssl/err.h>
 #include <openssl/x509v3.h>
 #include <openssl/rand.h>
+#include <openssl/evp.h>
+#define nats_hash           EVP_MD_CTX
+#define NATS_HASH_MAX_LEN   EVP_MAX_MD_SIZE
 #else
-#define SSL             void*
-#define SSL_free(c)     { (c) = NULL; }
-#define SSL_CTX         void*
-#define SSL_CTX_free(c) { (c) = NULL; }
-#define NO_SSL_ERR  "The library was built without SSL support!"
+#define SSL                 void*
+#define SSL_free(c)         { (c) = NULL; }
+#define SSL_CTX             void*
+#define SSL_CTX_free(c)     { (c) = NULL; }
+#define NO_SSL_ERR          "The library was built without SSL support!"
+#define nats_hash           void
+#define NATS_HASH_MAX_LEN   32
 #endif
 
 #include "err.h"
@@ -106,6 +111,8 @@
 #define nats_IsStringEmpty(s) ((((s) == NULL) || ((s)[0] == '\0')) ? true : false)
 #define nats_HasPrefix(_s, _prefix) (nats_IsStringEmpty(_s) ? nats_IsStringEmpty(_prefix) : (strncmp((_s), (_prefix), strlen(_prefix)) == 0))
 
+#define __natsHeader natsStrHash
+
 static inline bool nats_StringEquals(const char *s1, const char *s2)
 {
     if (s1 == NULL)
@@ -147,6 +154,16 @@ static inline bool nats_StringEquals(const char *s1, const char *s2)
 
 #define NATS_MILLIS_TO_NANOS(d)     (((int64_t)d)*(int64_t)1E6)
 #define NATS_SECONDS_TO_NANOS(d)    (((int64_t)d)*(int64_t)1E9)
+#define NATS_NANOS_TO_MILLIS(d)     (((int64_t)d)/(int64_t)1E6)
+
+#if __STDC_VERSION__ >= 201112L
+#define NATS_GLOBAL_STATIC_ASSERT(_cond, _message_as_id) \
+    _Static_assert(_cond, #_message_as_id)
+#else
+// for C99 we define explicitly
+#define NATS_GLOBAL_STATIC_ASSERT(_cond, _message_as_id) \
+    typedef char static_assertion_##_message_as_id[(_cond) ? 1 : -1]
+#endif
 
 extern int64_t gLockSpinCount;
 
@@ -187,10 +204,10 @@ typedef struct __natsSSLCtx
     SSL_CTX         *ctx;
     char            *expectedHostname;
     bool            skipVerify;
-
-#ifdef NATS_WITH_EXPERIMENTAL
-    SSL_verify_cb   callback;
-#endif // NATS_WITH_EXPERIMENTAL
+    char            *certFileName;
+    char            *keyFileName;
+    natsSSLVerifyCb callback;
+    bool            firstHandshake;
 
 } natsSSLCtx;
 
@@ -230,6 +247,7 @@ struct __natsOptions
     bool                    allowReconnect;
     bool                    secure;
     bool                    tlsHandshakeFirst;
+    bool                    tlsConcurrentHandshakes;
     int                     ioBufSize;
     int                     maxReconnect;
     int64_t                 reconnectWait;
@@ -268,6 +286,9 @@ struct __natsOptions
     natsConnectionHandler   microClosedCb;
     natsErrHandler          microAsyncErrCb;
 
+    natsProxyConnHandler    proxyConnectCb;
+    void                    *proxyConnectClosure;
+
     int64_t                 pingInterval;
     int                     maxPingsOut;
     int                     maxPendingMsgs;
@@ -356,6 +377,8 @@ typedef struct __pmInfo
 
 } pmInfo;
 
+typedef void (*js_onReleaseCb)(void *arg);
+
 struct __jsCtx
 {
     natsMutex		    *mu;
@@ -374,6 +397,8 @@ struct __jsCtx
     int64_t             pmcount;
     int                 stalled;
     bool                closed;
+    js_onReleaseCb      onReleaseCb;
+    void                *onReleaseCbArg;
 };
 
 typedef struct __jsFetch
@@ -393,6 +418,9 @@ typedef struct __jsFetch
     // Timer for the fetch expiration. We leverage the existing jsi->hbTimer for
     // checking missed heartbeats.
     natsTimer   *expiresTimer;
+
+    // Pin ID if pinned by the server
+    char        *pinID;
 } jsFetch;
 
 typedef struct __jsSub
@@ -510,6 +538,60 @@ struct __kvWatcher
 
 };
 
+struct __objStore
+{
+    natsMutex           *mu;
+    int                 refs;
+    jsCtx               *js;
+    jsCtx               *pushJS;
+    char                *name;
+    char                *streamName;
+
+};
+
+struct __objStorePut
+{
+    natsMutex           *mu;
+    int                 refs;
+    objStore            *obs;
+    char                *echunkSubj;
+    objStoreInfo        *info;
+    jsCtx               *pubJS;
+    char                *metaSubj;
+    char                *chunkSubj;
+    nats_hash           *h;
+    uint32_t            sent;
+    uint64_t            total;
+    natsStatus          err;
+    char                *errTxt;
+    bool                pcof;
+
+};
+
+struct __objStoreGet
+{
+    objStore            *obs;
+    objStoreInfo        *info;
+    nats_hash           *digest;
+    natsSubscription    *sub;
+    uint64_t            remaining;
+    bool                done;
+
+};
+
+struct __objStoreWatcher
+{
+    natsMutex           *mu;
+    int                 refs;
+    objStore            *obs;
+    natsSubscription    *sub;
+    bool                initDone;
+    bool                retMarker;
+    bool                ignoreDel;
+    bool                stopped;
+
+};
+
 typedef struct __natsSubscriptionControlMessages
 {
     struct
@@ -641,22 +723,26 @@ typedef struct __natsPongList
 
 typedef struct __natsSockCtx
 {
-    natsSock        fd;
-    bool            fdActive;
+    natsSock                fd;
+    bool                    fdActive;
 
-    natsDeadline    readDeadline;
-    natsDeadline    writeDeadline;
+    natsDeadline            readDeadline;
+    natsDeadline            writeDeadline;
 
-    SSL             *ssl;
+    SSL                     *ssl;
+    natsMutex               *sslMu;
 
     // This is true when we are using an external event loop (such as libuv).
-    bool            useEventLoop;
+    bool                    useEventLoop;
 
-    int             orderIP; // possible values: 0,4,6,46,64
+    int                     orderIP; // possible values: 0,4,6,46,64
 
     // By default, the list of IPs returned by the hostname resolution will
     // be shuffled. This option, if `true`, will disable the shuffling.
-    bool            noRandomize;
+    bool                    noRandomize;
+
+    natsProxyConnHandler    proxyConnectCb;
+    void                    *proxyConnectClosure;
 
 } natsSockCtx;
 
@@ -733,6 +819,12 @@ struct __natsConnection
     natsThread          *drainThread;
     int64_t             drainTimeout;
     bool                dontSendInPlace;
+    // These below will be protected by the `subsMu` lock.
+    natsCondition       *drainCond;
+    int                 drainSubCountTarget;
+    bool                drainSubSignalOnRemove;
+    bool                drainExcludeRespMux;
+    bool                drainConnClosed;
 
     // Set to true when owned by a Streaming connection,
     // which will prevent user from calling Close and/or Destroy.
@@ -759,6 +851,7 @@ struct __natsConnection
     {
         bool            attached;
         bool            writeAdded;
+        bool            retained;   // Will be set to true at the very first successful attach.
         void            *buffer;
         void            *data;
     } el;
@@ -778,10 +871,26 @@ struct __natsConnection
 };
 
 void
-nats_sslRegisterThreadForCleanup(void);
+nats_setNATSThreadKey(void);
+
+//
+// SHA256
+//
+void
+nats_hashNoErrorOnNoSSL(bool noError);
+
+natsStatus
+nats_hashNew(nats_hash **new_hash);
+
+natsStatus
+nats_hashWrite(nats_hash *hash, const void *data, int dataLen);
+
+natsStatus
+nats_hashSum(nats_hash *hash, unsigned char *digest, unsigned int *len);
 
 void
-nats_setNATSThreadKey(void);
+nats_hashDestroy(nats_hash *hash);
+
 
 //
 // Threads
