@@ -1,4 +1,4 @@
-// Copyright 2015-2024 The NATS Authors
+// Copyright 2015-2025 The NATS Authors
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
 // You may obtain a copy of the License at
@@ -233,6 +233,8 @@ natsSSLCtx_release(natsSSLCtx *ctx)
     if (refs == 0)
     {
         NATS_FREE(ctx->expectedHostname);
+        NATS_FREE(ctx->certFileName);
+        NATS_FREE(ctx->keyFileName);
         SSL_CTX_free(ctx->ctx);
         natsMutex_Destroy(ctx->lock);
         NATS_FREE(ctx);
@@ -269,11 +271,7 @@ _createSSLCtx(natsSSLCtx **newCtx)
     }
     if (s == NATS_OK)
     {
-#if defined(NATS_USE_OPENSSL_1_1)
         ctx->ctx = SSL_CTX_new(TLS_client_method());
-#else
-        ctx->ctx = SSL_CTX_new(TLSv1_2_client_method());
-#endif
         if (ctx->ctx == NULL)
             s = nats_setError(NATS_SSL_ERROR,
                               "Unable to create SSL context: %s",
@@ -284,14 +282,10 @@ _createSSLCtx(natsSSLCtx **newCtx)
     {
         (void) SSL_CTX_set_mode(ctx->ctx, SSL_MODE_AUTO_RETRY);
 
-#if defined(NATS_USE_OPENSSL_1_1)
         SSL_CTX_set_min_proto_version(ctx->ctx, TLS1_2_VERSION);
-#else
-        SSL_CTX_set_options(ctx->ctx, SSL_OP_NO_SSLv2);
-        SSL_CTX_set_options(ctx->ctx, SSL_OP_NO_SSLv3);
-#endif
         SSL_CTX_set_default_verify_paths(ctx->ctx);
 
+        ctx->firstHandshake = true;
         *newCtx = ctx;
     }
     else if (ctx != NULL)
@@ -305,32 +299,37 @@ _createSSLCtx(natsSSLCtx **newCtx)
 static natsStatus
 _getSSLCtx(natsOptions *opts)
 {
-    natsStatus s;
+    natsStatus s = NATS_OK;
 
-    s = nats_initSSL();
-    if ((s == NATS_OK) && (opts->sslCtx != NULL))
+    if (opts->sslCtx != NULL)
     {
-        bool createNew = false;
+        bool fail = false;
 
         natsMutex_Lock(opts->sslCtx->lock);
 
-        // If this context is retained by a cloned natsOptions, we need to
-        // release it and create a new context.
+        // If this context is retained by a cloned natsOptions, we can't
+        // continue because we can't alter the SSL_CTX while it is being
+        // used by the connections that have a reference to it. We can't
+        // simply create a new context here (like we used to) because it
+        // would be "empty" and users may think that it is already
+        // configured with all the previous options (which would not be
+        // the case). We have to fail the parent call so that the users
+        // create a new natsOptions object instead, and reconfigure from
+        // scratch, or wait for referencing connections to be destroyed.
         if (opts->sslCtx->refs > 1)
-            createNew = true;
+            fail = true;
 
         natsMutex_Unlock(opts->sslCtx->lock);
 
-        if (createNew)
+        if (fail)
         {
-            natsSSLCtx_release(opts->sslCtx);
-            opts->sslCtx = NULL;
-        }
-        else
-        {
-            // We can use this ssl context.
-            return NATS_OK;
+            return nats_setError(NATS_ILLEGAL_STATE, "%s",
+                "This natsOptions object can't be modified because it is "\
+                "configured for SSL and is currently used by connection(s)!");
         }
+
+        // We can use this ssl context.
+        return NATS_OK;
     }
 
     if (s == NATS_OK)
@@ -371,9 +370,10 @@ natsOptions_TLSHandshakeFirst(natsOptions *opts)
 
     LOCK_AND_CHECK_OPTIONS(opts, 0);
 
-    s = natsOptions_SetSecure(opts, true);
+    s = _getSSLCtx(opts);
     if (s == NATS_OK)
     {
+        opts->secure            = true;
         opts->tlsHandshakeFirst = true;
     }
 
@@ -382,6 +382,22 @@ natsOptions_TLSHandshakeFirst(natsOptions *opts)
     return NATS_UPDATE_ERR_STACK(s);
 }
 
+natsStatus
+natsOptions_AllowConcurrentTLSHandshakes(natsOptions *opts)
+{
+    natsStatus s = NATS_OK;
+
+    LOCK_AND_CHECK_OPTIONS(opts, 0);
+
+    s = _getSSLCtx(opts);
+    if (s == NATS_OK)
+        opts->tlsConcurrentHandshakes = true;
+
+    UNLOCK_OPTS(opts);
+
+    return NATS_UPDATE_ERR_STACK(s);
+}
+
 natsStatus
 natsOptions_LoadCATrustedCertificates(natsOptions *opts, const char *fileName)
 {
@@ -392,8 +408,6 @@ natsOptions_LoadCATrustedCertificates(natsOptions *opts, const char *fileName)
     s = _getSSLCtx(opts);
     if (s == NATS_OK)
     {
-        nats_sslRegisterThreadForCleanup();
-
         if (SSL_CTX_load_verify_locations(opts->sslCtx->ctx, fileName, NULL) != 1)
         {
             s = nats_setError(NATS_SSL_ERROR,
@@ -408,6 +422,30 @@ natsOptions_LoadCATrustedCertificates(natsOptions *opts, const char *fileName)
     return s;
 }
 
+natsStatus
+natsOptions_LoadCATrustedCertificatesPath(natsOptions *opts, const char *path)
+{
+    natsStatus s = NATS_OK;
+
+    LOCK_AND_CHECK_OPTIONS(opts, ((path == NULL) || (path[0] == '\0')));
+
+    s = _getSSLCtx(opts);
+    if (s == NATS_OK)
+    {
+        if (SSL_CTX_load_verify_locations(opts->sslCtx->ctx, NULL, path) != 1)
+        {
+            s = nats_setError(NATS_SSL_ERROR,
+                              "Error loading trusted certificates in path '%s': %s",
+                              path,
+                              NATS_SSL_ERR_REASON_STRING);
+        }
+    }
+
+    UNLOCK_OPTS(opts);
+
+    return s;
+}
+
 natsStatus
 natsOptions_SetCATrustedCertificates(natsOptions *opts, const char *certs)
 {
@@ -429,8 +467,6 @@ natsOptions_SetCATrustedCertificates(natsOptions *opts, const char *certs)
         STACK_OF(X509_INFO) *inf  = NULL;
         int i;
 
-        nats_sslRegisterThreadForCleanup();
-
         cts = SSL_CTX_get_cert_store(opts->sslCtx->ctx);
         if (cts == NULL)
         {
@@ -504,8 +540,6 @@ natsOptions_LoadCertificatesChain(natsOptions *opts,
     s = _getSSLCtx(opts);
     if (s == NATS_OK)
     {
-        nats_sslRegisterThreadForCleanup();
-
         if (SSL_CTX_use_certificate_chain_file(opts->sslCtx->ctx, certFileName) != 1)
         {
             s = nats_setError(NATS_SSL_ERROR,
@@ -530,6 +564,77 @@ natsOptions_LoadCertificatesChain(natsOptions *opts,
     return s;
 }
 
+static int
+_sslCertCallback(SSL* ssl, void* arg)
+{
+    natsSSLCtx *ctx = (natsSSLCtx*)arg;
+    if (ctx == NULL)
+        return 0;
+
+    // delete any certificates associated with the SSL object
+    SSL_certs_clear(ssl);
+
+    if (SSL_use_certificate_chain_file(ssl, ctx->certFileName) != 1)
+    {
+        nats_setError(NATS_SSL_ERROR,
+                      "Error loading certificate chain '%s': %s",
+                      ctx->certFileName,
+                      NATS_SSL_ERR_REASON_STRING);
+        return 0;
+    }
+
+    if (SSL_use_PrivateKey_file(ssl, ctx->keyFileName, SSL_FILETYPE_PEM) != 1)
+    {
+        nats_setError(NATS_SSL_ERROR,
+                      "Error loading private key '%s': %s",
+                      ctx->keyFileName,
+                      NATS_SSL_ERR_REASON_STRING);
+        return 0;
+    }
+
+    return 1;
+}
+
+natsStatus
+natsOptions_LoadCertificatesChainDynamic(natsOptions *opts,
+                                  const char *certFileName,
+                                  const char *keyFileName)
+{
+    natsStatus s = NATS_OK;
+
+    if (nats_IsStringEmpty(certFileName) || nats_IsStringEmpty(keyFileName))
+    {
+        return nats_setError(NATS_INVALID_ARG, "%s",
+                             "certificate and key file names can't be NULL nor empty");
+    }
+
+    LOCK_AND_CHECK_OPTIONS(opts, 0);
+
+    s = _getSSLCtx(opts);
+    if (s == NATS_OK)
+    {
+        NATS_FREE(opts->sslCtx->certFileName);
+        opts->sslCtx->certFileName = NATS_STRDUP(certFileName);
+        if (opts->sslCtx->certFileName == NULL)
+            s = nats_setDefaultError(NATS_NO_MEMORY);
+    }
+    if (s == NATS_OK)
+    {
+        NATS_FREE(opts->sslCtx->keyFileName);
+        opts->sslCtx->keyFileName = NATS_STRDUP(keyFileName);
+        if (opts->sslCtx->keyFileName == NULL)
+            s = nats_setDefaultError(NATS_NO_MEMORY);
+    }
+    if (s == NATS_OK)
+    {
+        SSL_CTX_set_cert_cb(opts->sslCtx->ctx, _sslCertCallback, opts->sslCtx);
+    }
+
+    UNLOCK_OPTS(opts);
+
+    return s;
+}
+
 natsStatus
 natsOptions_SetCertificatesChain(natsOptions *opts, const char *certStr, const char *keyStr)
 {
@@ -549,8 +654,6 @@ natsOptions_SetCertificatesChain(natsOptions *opts, const char *certStr, const c
         X509 *cert = NULL;
         BIO  *bio  = NULL;
 
-        nats_sslRegisterThreadForCleanup();
-
         bio = BIO_new_mem_buf((char*) certStr, -1);
         if ((bio == NULL) || ((cert = PEM_read_bio_X509(bio, NULL, 0, NULL)) == NULL))
         {
@@ -609,8 +712,6 @@ natsOptions_SetCiphers(natsOptions *opts, const char *ciphers)
     s = _getSSLCtx(opts);
     if (s == NATS_OK)
     {
-        nats_sslRegisterThreadForCleanup();
-
         if (SSL_CTX_set_cipher_list(opts->sslCtx->ctx, ciphers) != 1)
         {
             s = nats_setError(NATS_SSL_ERROR,
@@ -630,14 +731,11 @@ natsOptions_SetCipherSuites(natsOptions *opts, const char *ciphers)
 {
     natsStatus s = NATS_OK;
 
-#if defined(NATS_USE_OPENSSL_1_1)
     LOCK_AND_CHECK_OPTIONS(opts, 0);
 
     s = _getSSLCtx(opts);
     if (s == NATS_OK)
     {
-        nats_sslRegisterThreadForCleanup();
-
         if (SSL_CTX_set_ciphersuites(opts->sslCtx->ctx, ciphers) != 1)
         {
             s = nats_setError(NATS_SSL_ERROR,
@@ -648,9 +746,6 @@ natsOptions_SetCipherSuites(natsOptions *opts, const char *ciphers)
     }
 
     UNLOCK_OPTS(opts);
-#else
-    s = nats_setError(NATS_ERR, "%s", "Setting TLSv1.3 ciphersuites requires OpenSSL 1.1+");
-#endif
 
     return s;
 }
@@ -695,10 +790,8 @@ natsOptions_SkipServerVerification(natsOptions *opts, bool skip)
     if (s == NATS_OK)
     {
         opts->sslCtx->skipVerify = skip;
-#ifdef NATS_WITH_EXPERIMENTAL
         if (skip)
             opts->sslCtx->callback = NULL;
-#endif // NATS_WITH_EXPERIMENTAL
     }
 
     UNLOCK_OPTS(opts);
@@ -706,10 +799,8 @@ natsOptions_SkipServerVerification(natsOptions *opts, bool skip)
     return s;
 }
 
-#ifdef NATS_WITH_EXPERIMENTAL
-
 natsStatus
-natsOptions_SetSSLVerificationCallback(natsOptions *opts, SSL_verify_cb callback)
+natsOptions_SetSSLVerificationCallback(natsOptions *opts, natsSSLVerifyCb callback)
 {
     natsStatus s = NATS_OK;
 
@@ -730,8 +821,6 @@ natsOptions_SetSSLVerificationCallback(natsOptions *opts, SSL_verify_cb callback
     return s;
 }
 
-#endif // NATS_WITH_EXPERIMENTAL
-
 #else
 
 natsStatus
@@ -746,6 +835,12 @@ natsOptions_TLSHandshakeFirst(natsOptions *opts)
     return nats_setError(NATS_ILLEGAL_STATE, "%s", NO_SSL_ERR);
 }
 
+natsStatus
+natsOptions_AllowConcurrentTLSHandshakes(natsOptions *opts)
+{
+    return nats_setError(NATS_ILLEGAL_STATE, "%s", NO_SSL_ERR);
+}
+
 natsStatus
 natsOptions_LoadCATrustedCertificates(natsOptions *opts, const char *fileName)
 {
@@ -790,17 +885,12 @@ natsOptions_SkipServerVerification(natsOptions *opts, bool skip)
     return nats_setError(NATS_ILLEGAL_STATE, "%s", NO_SSL_ERR);
 }
 
-
-#ifdef NATS_WITH_EXPERIMENTAL
-
 natsStatus
-natsOptions_SetSSLVerificationCallback(natsOptions *opts, SSL_verify_cb callback)
+natsOptions_SetSSLVerificationCallback(natsOptions *opts, natsSSLVerifyCb callback)
 {
     return nats_setError(NATS_ILLEGAL_STATE, "%s", NO_SSL_ERR);
 }
 
-#endif // NATS_WITH_EXPERIMENTAL
-
 #endif
 
 natsStatus
@@ -963,6 +1053,19 @@ natsOptions_SetMaxPendingBytes(natsOptions* opts, int64_t maxPending)
     return NATS_OK;
 }
 
+natsStatus
+natsOptions_SetProxyConnHandler(natsOptions* opts, natsProxyConnHandler proxyConnHandler, void *closure)
+{
+    LOCK_AND_CHECK_OPTIONS(opts, 0)
+
+    opts->proxyConnectCb        = proxyConnHandler;
+    opts->proxyConnectClosure   = closure;
+
+    UNLOCK_OPTS(opts);
+
+    return NATS_OK;
+}
+
 natsStatus
 natsOptions_SetErrorHandler(natsOptions *opts, natsErrHandler errHandler,
                             void *closure)
