@@ -11,6 +11,8 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
+#include <assert.h>
+
 #include "natsp.h"
 
 static const char *statusText[] = {
@@ -72,8 +74,12 @@ static const char *statusText[] = {
     "Mismatch",
     "Missed Server Heartbeat",
     "Limit reached",
+
+    "Jetstream Consumer PinID Mismatch",
 };
 
+NATS_GLOBAL_STATIC_ASSERT(NATS_MAX_STATUS_VALUE == sizeof(statusText)/sizeof(statusText[0]), Incorrect_array_size);
+
 const char*
 natsStatus_GetText(natsStatus s) {
     return statusText[(int) s];
