@@ -1,4 +1,4 @@
-// Copyright 2015-2023 The NATS Authors
+// Copyright 2015-2025 The NATS Authors
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
 // You may obtain a copy of the License at
@@ -1242,6 +1242,12 @@ nats_JSONGetUInt16(nats_JSON *json, const char *fieldName, uint16_t *value)
     JSON_GET_AS(TYPE_UINT, uint16_t);
 }
 
+natsStatus
+nats_JSONGetUInt32(nats_JSON *json, const char *fieldName, uint32_t *value)
+{
+    JSON_GET_AS(TYPE_UINT, uint32_t);
+}
+
 natsStatus
 nats_JSONGetBool(nats_JSON *json, const char *fieldName, bool *value)
 {
@@ -1865,6 +1871,13 @@ nats_Base64RawURL_EncodeString(const unsigned char *src, int srcLen, char **pDes
     return NATS_UPDATE_ERR_STACK(s);
 }
 
+natsStatus
+nats_Base64URL_EncodeString(const unsigned char *src, int srcLen, char **pDest)
+{
+    natsStatus s = _base64Encode(base64EncodeURL, true, src, srcLen, pDest);
+    return NATS_UPDATE_ERR_STACK(s);
+}
+
 natsStatus
 nats_Base64_Encode(const unsigned char *src, int srcLen, char **pDest)
 {
@@ -2287,17 +2300,22 @@ fmt_int(char *buf, int w, uint64_t v)
     return w;
 }
 
-natsStatus
-nats_marshalDuration(natsBuffer *out_buf, bool comma, const char *field_name, int64_t d)
+// Converts a number of nanoseconds to a go duration string.
+// Note: buf must be at least 32 bytes long.
+// This is the maximum size of a duration string.
+// The format is: "2540400h10m10.000000000s".
+// Returns the pointer to the beginning of the string (in buf).
+char *
+nats_formatDuration(char *buf, int64_t d)
 {
-    // Largest time is 2540400h10m10.000000000s
-    char buf[32];
-    int w = 32;
     bool neg = d < 0;
     uint64_t u = (uint64_t) (neg ? -d : d);
     int prec;
-    natsStatus s = NATS_OK;
-    const char *start = (comma ? ",\"" : "\"");
+
+    // Largest time is 2540400h10m10.000000000s
+    int w = 32;
+    w--;
+    buf[w] = '\0';
 
     if (u < 1000000000)
     {
@@ -2307,12 +2325,7 @@ nats_marshalDuration(natsBuffer *out_buf, bool comma, const char *field_name, in
         buf[w] = 's';
         w--;
         if (u == 0)
-        {
-            s = natsBuf_Append(out_buf, start, -1);
-            IFOK(s, natsBuf_Append(out_buf, field_name, -1));
-            IFOK(s, natsBuf_Append(out_buf, "\":\"0s\"", -1));
-            return NATS_UPDATE_ERR_STACK(s);
-        }
+            return buf+w;
         else if (u < 1000)
         {
             // print nanoseconds
@@ -2373,10 +2386,23 @@ nats_marshalDuration(natsBuffer *out_buf, bool comma, const char *field_name, in
         buf[w] = '-';
     }
 
+    return buf+w;
+}
+
+natsStatus
+nats_marshalDuration(natsBuffer *out_buf, bool comma, const char *field_name, int64_t d)
+{
+    // Largest time is 2540400h10m10.000000000s
+    char buf[32];
+    natsStatus s = NATS_OK;
+    const char *start = (comma ? ",\"" : "\"");
+
+    char *dur = nats_formatDuration(buf, d);
+
     s = natsBuf_Append(out_buf, start, -1);
     IFOK(s, natsBuf_Append(out_buf, field_name, -1));
     IFOK(s, natsBuf_Append(out_buf, "\":\"", -1));
-    IFOK(s, natsBuf_Append(out_buf, buf + w, sizeof(buf) - w));
+    IFOK(s, natsBuf_Append(out_buf, dur, -1));
     IFOK(s, natsBuf_Append(out_buf, "\"", -1));
     return NATS_UPDATE_ERR_STACK(s);
 }
@@ -2434,28 +2460,52 @@ bool nats_IsSubjectValid(const char *subject, bool wcAllowed)
     return true;
 }
 
+// Bitmap of allowed ASCII characters (0–127)
+// Allowed: A–Z, a–z, 0–9, '-', '_', '/', '='
+static const uint8_t _limited_term_allowed_bitmap[16] = { 0x00, 0x00, 0x00, 0x00, 0x00, 0xa0, 0xff, 0x23, 0xfe, 0xff, 0xff, 0x87, 0xfe, 0xff, 0xff, 0x07};
+
+// Validates limited_term, see
+// https://github.com/nats-io/nats-architecture-and-design/blob/8693d2263e137e23748e3df583fd58247e4e48b7/adr/ADR-6.md?plain=1#L48
 natsStatus
-nats_marshalMetadata(natsBuffer *buf, bool comma, const char *fieldName, natsMetadata md)
+nats_validateLimitedTerm(const char *name, const char *term)
+{
+
+    if (nats_IsStringEmpty(term))
+        return nats_setError(NATS_INVALID_ARG, "%s must not be empty", name);
+
+    for (int i=0; term[i] != '\0'; ++i) {
+        if (i >= 16)
+            return nats_setError(NATS_INVALID_ARG, "%s must not be longer than 16 characters", name);
+
+        unsigned char c = (unsigned char)term[i];
+        if ((c >= 128) || !(_limited_term_allowed_bitmap[c / 8] & (1 << (c % 8))))
+            return nats_setError(NATS_INVALID_ARG, "%s must contain only [A-Za-z0-9-_/=]", name);
+    }
+    return NATS_OK;
+}
+
+natsStatus
+nats_marshalMetadata(natsBuffer *buf, bool comma, const char *fieldName, natsMetadata *md)
 {
     natsStatus s = NATS_OK;
     int i;
     const char *start = (comma ? ",\"" : "\"");
 
-    if (md.Count <= 0)
+    if ((md == NULL) || (md->Count <= 0))
         return NATS_OK;
 
     IFOK(s, natsBuf_Append(buf, start, -1));
     IFOK(s, natsBuf_Append(buf, fieldName, -1));
     IFOK(s, natsBuf_Append(buf, "\":{", 3));
-    for (i = 0; (s == NATS_OK) && (i < md.Count); i++)
+    for (i = 0; (s == NATS_OK) && (i < md->Count); i++)
     {
         IFOK(s, natsBuf_AppendByte(buf, '"'));
-        IFOK(s, natsBuf_Append(buf, md.List[i * 2], -1));
+        IFOK(s, natsBuf_Append(buf, md->List[i * 2], -1));
         IFOK(s, natsBuf_Append(buf, "\":\"", 3));
-        IFOK(s, natsBuf_Append(buf, md.List[i * 2 + 1], -1));
+        IFOK(s, natsBuf_Append(buf, md->List[i * 2 + 1], -1));
         IFOK(s, natsBuf_AppendByte(buf, '"'));
 
-        if (i != md.Count - 1)
+        if (i != md->Count - 1)
             IFOK(s, natsBuf_AppendByte(buf, ','));
     }
     IFOK(s, natsBuf_AppendByte(buf, '}'));
@@ -2508,26 +2558,26 @@ nats_unmarshalMetadata(nats_JSON *json, const char *fieldName, natsMetadata *md)
 }
 
 natsStatus
-nats_cloneMetadata(natsMetadata *clone, natsMetadata md)
+nats_cloneMetadata(natsMetadata *clone, natsMetadata *md)
 {
-    natsStatus s = NATS_OK;
-    int i = 0;
-    int n;
-    char **list = NULL;
+    natsStatus  s       = NATS_OK;
+    char        **list  = NULL;
+    int         i       = 0;
+    int         n;
 
     clone->Count = 0;
     clone->List = NULL;
-    if (md.Count == 0)
+    if ((md == NULL) || (md->Count == 0))
         return NATS_OK;
 
-    n = md.Count * 2;
+    n = md->Count * 2;
     list = NATS_CALLOC(n, sizeof(char *));
     if (list == NULL)
         s = nats_setDefaultError(NATS_NO_MEMORY);
 
     for (i = 0; (s == NATS_OK) && (i < n); i++)
     {
-        list[i] = NATS_STRDUP(md.List[i]);
+        list[i] = NATS_STRDUP(md->List[i]);
         if (list[i] == NULL)
             s = nats_setDefaultError(NATS_NO_MEMORY);
     }
@@ -2535,7 +2585,7 @@ nats_cloneMetadata(natsMetadata *clone, natsMetadata md)
     if (s == NATS_OK)
     {
         clone->List = (const char **)list;
-        clone->Count = md.Count;
+        clone->Count = md->Count;
     }
     else
     {
@@ -2568,48 +2618,11 @@ nats_freeMetadata(natsMetadata *md)
 natsStatus nats_formatStringArray(char **out, const char **strings, int count)
 {
     natsStatus s = NATS_OK;
-    natsBuffer buf;
-    int len = 0;
-    int  i;
+    natsBuffer buf = { 0 };
 
-    len++; // For the '['
-    for (i = 0; i < count; i++)
-    {
-        len += 2; // For the quotes
-        if (i > 0)
-            len++; // For the ','
-        if (strings[i] == NULL)
-            len += (int)strlen("(null)");
-        else
-            len += (int)strlen(strings[i]);
-    }
-    len++; // For the ']'
-    len++; // For the '\0'
-
-    s = natsBuf_Init(&buf, len);
-
-    natsBuf_AppendByte(&buf, '[');
-    for (i = 0; (s == NATS_OK) && (i < count); i++)
-    {
-        if (i > 0)
-        {
-            IFOK(s, natsBuf_AppendByte(&buf, ','));
-        }
-        IFOK(s, natsBuf_AppendByte(&buf, '"'));
-        if (strings[i] == NULL)
-        {
-            IFOK(s, natsBuf_Append(&buf, "(null)", -1));
-        }
-        else
-        {
-            IFOK(s, natsBuf_Append(&buf, strings[i], -1));
-        }
-        IFOK(s, natsBuf_AppendByte(&buf, '"'));
-    }
-
-    IFOK(s, natsBuf_AppendByte(&buf, ']'));
+    s = natsBuf_Init(&buf, 128);
+    IFOK(s, nats_marshalStringArray(&buf, false, NULL, strings, count));
     IFOK(s, natsBuf_AppendByte(&buf, '\0'));
-
     if (s != NATS_OK)
     {
         natsBuf_Cleanup(&buf);
@@ -2619,3 +2632,193 @@ natsStatus nats_formatStringArray(char **out, const char **strings, int count)
     *out = natsBuf_Data(&buf);
     return NATS_OK;
 }
+
+// note: does not JSON-escape the strings
+natsStatus
+nats_marshalStringArray(natsBuffer *buf, bool comma, const char *fieldName, const char **values, int len)
+{
+    natsStatus  s = NATS_OK;
+    int         i;
+
+    if (!nats_IsStringEmpty(fieldName))
+    {
+        if (comma)
+            s = natsBuf_AppendByte(buf, ',');
+        IFOK(s, natsBuf_AppendByte(buf, '"'));
+        IFOK(s, natsBuf_Append(buf, fieldName, -1));
+        IFOK(s, natsBuf_AppendByte(buf, '"'));
+        IFOK(s, natsBuf_AppendByte(buf, ':'));
+    }
+
+    natsBuf_AppendByte(buf, '[');
+    for (i = 0; (s == NATS_OK) && (i < len); i++)
+    {
+        if (i > 0)
+        {
+            IFOK(s, natsBuf_AppendByte(buf, ','));
+        }
+        IFOK(s, natsBuf_AppendByte(buf, '"'));
+        if (values[i] == NULL)
+        {
+            IFOK(s, natsBuf_Append(buf, "(null)", -1));
+        }
+        else
+        {
+            IFOK(s, natsBuf_Append(buf, values[i], -1));
+        }
+        IFOK(s, natsBuf_AppendByte(buf, '"'));
+    }
+
+    IFOK(s, natsBuf_AppendByte(buf, ']'));
+    return NATS_UPDATE_ERR_STACK(s);
+}
+
+natsStatus
+nats_marshalTimeUTC(natsBuffer *buf, bool comma, const char *fieldName, int64_t timeUTC)
+{
+    natsStatus  s  = NATS_OK;
+    char        dbuf[36] = {'\0'};
+
+    s = nats_EncodeTimeUTC(dbuf, sizeof(dbuf), timeUTC);
+    if (s != NATS_OK)
+        return nats_setError(NATS_ERR, "unable to encode data for field '%s' value %" PRId64, fieldName, timeUTC);
+
+    if (comma)
+        s = natsBuf_AppendByte(buf, ',');
+
+    IFOK(s, natsBuf_AppendByte(buf, '"'));
+    IFOK(s, natsBuf_Append(buf, fieldName, -1));
+    IFOK(s, natsBuf_Append(buf, "\":\"", -1));
+    IFOK(s, natsBuf_Append(buf, dbuf, -1));
+    IFOK(s, natsBuf_AppendByte(buf, '"'));
+
+    return NATS_UPDATE_ERR_STACK(s);
+}
+
+natsStatus
+nats_marshalString(natsBuffer *buf, bool omitEmpty, bool comma, const char *fieldName, const char *str)
+{
+    natsStatus  s = NATS_OK;
+
+    if (omitEmpty && nats_IsStringEmpty(str))
+        return NATS_OK;
+
+    if (comma)
+        s = natsBuf_AppendByte(buf, ',');
+
+    IFOK(s, natsBuf_AppendByte(buf, '"'));
+    IFOK(s, natsBuf_Append(buf, fieldName, -1));
+    IFOK(s, natsBuf_Append(buf, "\":\"", -1));
+    IFOK(s, natsBuf_Append(buf, str, -1));
+    IFOK(s, natsBuf_AppendByte(buf, '"'));
+
+    return NATS_UPDATE_ERR_STACK(s);
+}
+
+bool
+nats_validBucketName(const char *bucket)
+{
+    int     i;
+    char    c;
+
+    if (nats_IsStringEmpty(bucket))
+        return false;
+
+    for (i=0; i<(int)strlen(bucket); i++)
+    {
+        c = bucket[i];
+        if ((isalnum((unsigned char) c) == 0) && (c != '_') && (c != '-'))
+            return false;
+    }
+    return true;
+}
+
+static natsStatus
+_addHeader(void *userInfo, const char *fieldName, nats_JSONField *f)
+{
+    natsStatus      s       = NATS_OK;
+    natsHeader      *h      = (natsHeader*) userInfo;
+    nats_JSONArray  *arr    = f->value.varr;
+    int             i;
+
+    for (i=0; (s == NATS_OK) && (i<arr->size); i++)
+        s = natsHeader_Add(h, fieldName, (const char*) arr->values[i]);
+    return NATS_UPDATE_ERR_STACK(s);
+}
+
+natsStatus
+nats_unmarshalHeader(nats_JSON *json, const char *fieldName, natsHeader **new_header)
+{
+    natsStatus  s       = NATS_OK;
+    nats_JSON   *hJSON  = NULL;
+    natsHeader  *h      = NULL;
+
+    *new_header = NULL;
+
+    s = nats_JSONGetObject(json, fieldName, &hJSON);
+    if (s != NATS_OK)
+        return NATS_UPDATE_ERR_STACK(s);
+
+    if ((hJSON == NULL) || (natsStrHash_Count(hJSON->fields) == 0))
+        return NATS_OK;
+
+    s = natsHeader_New(&h);
+    IFOK(s, nats_JSONRange(hJSON, TYPE_ARRAY, 0, _addHeader, (void*) h));
+    if (s == NATS_OK)
+        *new_header = h;
+    else
+        natsHeader_Destroy(h);
+
+    return NATS_UPDATE_ERR_STACK(s);
+}
+
+natsStatus
+nats_marshalHeader(natsBuffer *buf, bool omitEmpty, bool comma, const char *fieldName, natsHeader *header)
+{
+    natsStatus  s = NATS_OK;
+
+    // The function returns 0 if header is NULL.
+    if (omitEmpty && (natsHeader_KeysCount(header) == 0))
+        return NATS_OK;
+
+    if (comma)
+        s = natsBuf_AppendByte(buf, ',');
+    IFOK(s, natsBuf_AppendByte(buf, '\"'));
+    IFOK(s, natsBuf_Append(buf, fieldName, -1));
+    IFOK(s, natsBuf_Append(buf, "\":{", -1));
+    if (s == NATS_OK)
+    {
+        natsStrHashIter iter;
+        char            *key = NULL;
+        void            *p   = NULL;
+        natsHeaderValue *v   = NULL;
+        bool            first= true;
+
+        comma = false;
+        natsStrHashIter_Init(&iter, (natsStrHash*) header);
+        while ((s == NATS_OK) && natsStrHashIter_Next(&iter, &key, &p))
+        {
+            if (!first)
+                s = natsBuf_AppendByte(buf, ',');
+            IFOK(s, natsBuf_AppendByte(buf, '\"'));
+            IFOK(s, natsBuf_Append(buf, key, -1));
+            IFOK(s, natsBuf_Append(buf, "\":[", -1));
+
+            comma = false;
+            for (v = (natsHeaderValue*) p; (s == NATS_OK) && (v != NULL); v = v->next)
+            {
+                if (comma)
+                    s = natsBuf_AppendByte(buf, ',');
+                IFOK(s, natsBuf_AppendByte(buf, '\"'));
+                IFOK(s, natsBuf_Append(buf, v->value, -1));
+                IFOK(s, natsBuf_AppendByte(buf, '\"'));
+                comma = true;
+            }
+            IFOK(s, natsBuf_AppendByte(buf, ']'));
+            first = false;
+        }
+    }
+    IFOK(s, natsBuf_AppendByte(buf, '}'));
+
+    return NATS_UPDATE_ERR_STACK(s);
+}
